Asphodel Radio Frequencies

# Device Frequency Hopping or Fixed Frequency Behavior

Device | WMR Channel 0 Selected | WMR Channel 1-36 Selected
Fixed Frequency Devices
Micro Telemetry | Fixed Channel 36 | Fixed Channel 1-36
Quad Telemetry | Fixed Channel 36 | Fixed Channel 1-36
Hopping Only Devices
Coax Vibration (firmware <=1.3.2) | Hopping | Hopping
Mote | Hopping | Hopping
Fully Configurable Devices
Coax Vibration (firmware >=2.0.0) | Hopping | Fixed Channel 1-36
Equinox | Hopping | Fixed Channel 1-36
Phalanx | Hopping | Fixed Channel 1-36
Torricelli | Hopping | Fixed Channel 1-36
Yellowstone | Hopping | Fixed Channel 1-36

# Fixed Frequency Table

Asphodel Channel | Frequency (MHz) | Hopping Usage | 4MHz Spacing | 6MHz Spacing | 8MHz Spacing
36 | 2402 |  | X | X | X
1 | 2404 | X |  |  |
2 | 2406 | X | X |  |
3 | 2408 | X |  | X |
4 | 2410 | X | X |  | X
5 | 2412 | X |  |  |
6 | 2414 | X | X | X |
7 | 2416 | X |  |  |
8 | 2418 | X | X |  | X
9 | 2420 | X |  | X |
10 | 2422 | X | X |  |
11 | 2424 |  |  |  |
Advertisement | 2426 |  |
12 | 2428 | X |  |  |
13 | 2430 | X | X |  |
14 | 2432 | X |  |  |
Advertisement | 2434 |  |
15 | 2436 | X |  |  |
16 | 2438 | X | Optional |  |
Bootloader | 2440 |  |
17 | 2442 | X | Optional | Optional |
18 | 2444 | X |  |  |
19 | 2446 | X | X |  | Optional
20 | 2448 | X |  | X |
21 | 2450 | X | X |  |
22 | 2452 | X |  |  |
23 | 2454 | X | X | X | X
24 | 2456 | X |  |  |
25 | 2458 | X | X |  |
26 | 2460 | X |  | X |
27 | 2462 | X | X |  | X
28 | 2464 | X |  |  |
29 | 2466 | X | X | X |
30 | 2468 | X |  |  |
31 | 2470 |  | X |  | X
32 | 2472 | X |  | X |
33 | 2474 | X | X |  |
34 | 2476 | X |  |  |
Advertisement | 2478 |  |
35 | 2480 |  |  |  |
Available Channels: | 15-17 | 9-10 | 6-7